use clap::Parser;
use log::LevelFilter;

mod ast;
mod cliargs;
mod parser;
mod token;
mod tokeniser;
mod common;


fn main() {
    let cliargs = cliargs::CliArgs::parse();
    env_logger::builder()
        .format_timestamp(None)
        .filter(None, cliargs.get_logger_filter())
        .init();

    let mut tokeniser = tokeniser::Tokeniser::new();
    let mut parser = parser::Parser::new();
    for file in &cliargs.input {
        if let Err(_) = tokeniser.tokenise(file.as_path()) {
            break;
        }

        let tokens = tokeniser.tokens();
        let Ok(ast) = parser.parse(file, tokens) else {
            break;
        };
        dbg!(ast);
    }
}
